# Endpoint

::: pynetbox.core.endpoint.Endpoint
    handler: python
    options:
        members: true
    options:
        members:
            - all
            - choices
            - count
            - create
            - delete
            - filter
            - get
            - update
        show_source: true
        show_root_heading: true

::: pynetbox.core.endpoint.DetailEndpoint
    handler: python
    options:
        members: true
    options:
        members:
            - create
            - list
        show_source: true
        show_root_heading: true
